<?php
/**
 * This template is used to display the goal with [give_goal]
 */

$form        = new Give_Donate_Form( $form_id );
$goal_option = give_get_meta( $form->ID, '_give_goal_option', true );

// Sanity check - ensure form has pass all condition to show goal.
if ( ( isset( $args['show_goal'] ) && ! filter_var( $args['show_goal'], FILTER_VALIDATE_BOOLEAN ) )
     || empty( $form->ID )
     || ( is_singular( 'give_forms' ) && ! give_is_setting_enabled( $goal_option ) )
     || ! give_is_setting_enabled( $goal_option ) || 0 === $form->goal ) {
	return false;
}

$goal_format         = give_get_form_goal_format( $form_id );
$price               = give_get_meta( $form_id, '_give_set_price', true );
$color               = give_get_meta( $form_id, '_give_goal_color', true );
$show_text           = isset( $args['show_text'] ) ? filter_var( $args['show_text'], FILTER_VALIDATE_BOOLEAN ) : true;
$show_bar            = isset( $args['show_bar'] ) ? filter_var( $args['show_bar'], FILTER_VALIDATE_BOOLEAN ) : true;
$goal_progress_stats = give_goal_progress_stats( $form );

$income = $goal_progress_stats['raw_actual'];
$goal   = $goal_progress_stats['raw_goal'];


$progress           = $goal ? round( ( $income / $goal ) * 100, 2 ) : 0;
$progress_bar_value = $income >= $goal ? 100 : $progress;
$progress_bar_circle_value = $income >= $goal ? 1 : round( ( $income / $goal ), 2 );

/**
 * Filter the goal progress output
 *
 * @since 1.8.8
 */
$progress = apply_filters( 'give_goal_amount_funded_percentage_output', $progress, $form_id, $form );

$version = isset($args['version']) ? $args['version'] : '';
if ($version == 'v1') {
?>
    <div class="give-goal-progress">
    	<?php if ( ! empty( $show_bar ) ) : ?>

    		<div class="progress-bar-circle" data-value="<?php  echo esc_attr( $progress_bar_circle_value ); ?>" data-size="112" data-thickness="13" data-reverse="false" data-color="<?php echo esc_attr($color); ?>">
                <div class="raised" style="color: <?php echo esc_attr($color); ?>">
                    <?php echo '<span class="give-percentage">' . round( $progress ) . '<sup>%</sup></span>'; ?>
                </div>
            </div>

    	<?php endif; ?>

    </div><!-- /.goal-progress -->
<?php } else { ?>
    <div class="give-goal-progress">
        
        <?php if ( ! empty( $show_text ) ) : ?>
            <div class="total-goal">
                <?php
                /**
                 * Filter the give currency.
                 *
                 * @since 1.8.17
                 */
                $form_currency = apply_filters( 'give_goal_form_currency', give_get_currency( $form_id ), $form_id );

                /**
                 * Filter the income formatting arguments.
                 *
                 * @since 1.8.17
                 */
                $income_format_args = apply_filters( 'give_goal_income_format_args', array(
                    'sanitize' => false,
                    'currency' => $form_currency,
                    'decimal'  => false,
                ), $form_id );

                /**
                 * Filter the goal formatting arguments.
                 *
                 * @since 1.8.17
                 */
                $goal_format_args = apply_filters( 'give_goal_amount_format_args', array(
                    'sanitize' => false,
                    'currency' => $form_currency,
                    'decimal'  => false,
                ), $form_id );

                // Get formatted amount.
                $income = give_human_format_large_amount( give_format_amount( $income, $income_format_args ), array( 'currency' => $form_currency ) );
                $goal   = give_human_format_large_amount( give_format_amount( $goal, $goal_format_args ), array( 'currency' => $form_currency ) );

                echo sprintf( /* translators: 1: amount of income raised 2: goal target amount. */
                    __( '<span class="income">%1$s</span> of <span class="goal-text">%2$s</span> raised', 'crowdngo' ),
                    give_currency_filter( $income, array( 'form_id' => $form_id ) ),
                    give_currency_filter( $goal, array( 'form_id' => $form_id ) )
                );
                ?>
            </div>
        <?php endif; ?>

        <?php if ( ! empty( $show_bar ) ) : ?>
            <div class="progress-bar-circle" data-value="<?php  echo esc_attr( $progress_bar_circle_value ); ?>" data-size="72" data-thickness="9" data-reverse="false" data-color="<?php echo esc_attr($color); ?>">
                <div class="raised" style="color: <?php echo esc_attr($color); ?>">
                    <?php echo '<span class="give-percentage">' . round( $progress ) . '<sup>%</sup>' . '</span>'; ?>
                </div>
            </div>
        <?php endif; ?>

        <?php if ( ! empty( $show_text ) ) : ?>
            <?php crowdngo_give_display_sales(); ?>
        <?php endif; ?>
    </div>
<?php }