<?php

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Crowdngo_Elementor_Donations extends Elementor\Widget_Base {

	public function get_name() {
        return 'apus_element_donation';
    }

	public function get_title() {
        return esc_html__( 'Apus Donations', 'crowdngo' );
    }
    
	public function get_categories() {
        return [ 'crowdngo-elements' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
            'content_section',
            [
                'label' => esc_html__( 'Donations', 'crowdngo' ),
                'tab' => Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'number',
            [
                'label' => esc_html__( 'Limit', 'crowdngo' ),
                'type' => Elementor\Controls_Manager::TEXT,
                'input_type' => 'number',
                'placeholder' => esc_html__( 'Enter your limit donations here', 'crowdngo' ),
                'default' => 4
            ]
        );

        $this->add_control(
            'columns',
            [
                'label' => esc_html__( 'Columns', 'crowdngo' ),
                'type' => Elementor\Controls_Manager::TEXT,
                'input_type' => 'number',
                'placeholder' => esc_html__( 'Enter your column number here', 'crowdngo' ),
                'default' => 4
            ]
        );

        $this->add_control(
            'layout_type',
            [
                'label' => esc_html__( 'Layout Type', 'crowdngo' ),
                'type' => Elementor\Controls_Manager::SELECT,
                'options' => array(
                    'grid' => esc_html__('Grid', 'crowdngo'),
                    'carousel' => esc_html__('Carousel', 'crowdngo'),
                ),
                'default' => 'grid'
            ]
        );
        
        $this->add_control(
            'rows',
            [
                'label' => esc_html__( 'Rows', 'crowdngo' ),
                'type' => Elementor\Controls_Manager::TEXT,
                'input_type' => 'number',
                'placeholder' => esc_html__( 'Enter your rows number here', 'crowdngo' ),
                'default' => 1,
                'condition' => [
                    'layout_type' => 'carousel',
                ],
            ]
        );

        $this->add_control(
            'show_nav',
            [
                'label'         => esc_html__( 'Show Navigation', 'crowdngo' ),
                'type'          => Elementor\Controls_Manager::SWITCHER,
                'label_on'      => esc_html__( 'Show', 'crowdngo' ),
                'label_off'     => esc_html__( 'Hide', 'crowdngo' ),
                'return_value'  => true,
                'default'       => true,
                'condition' => [
                    'layout_type' => 'carousel',
                ],
            ]
        );

        $this->add_control(
            'show_pagination',
            [
                'label'         => esc_html__( 'Show Pagination', 'crowdngo' ),
                'type'          => Elementor\Controls_Manager::SWITCHER,
                'label_on'      => esc_html__( 'Show', 'crowdngo' ),
                'label_off'     => esc_html__( 'Hide', 'crowdngo' ),
                'return_value'  => true,
                'default'       => true,
                'condition' => [
                    'layout_type' => 'carousel',
                ],
            ]
        );

        $this->add_control(
            'autoplay',
            [
                'label'         => esc_html__( 'Autoplay', 'crowdngo' ),
                'type'          => Elementor\Controls_Manager::SWITCHER,
                'label_on'      => esc_html__( 'Yes', 'crowdngo' ),
                'label_off'     => esc_html__( 'No', 'crowdngo' ),
                'return_value'  => true,
                'default'       => true,
                'condition' => [
                    'layout_type' => 'carousel',
                ],
            ]
        );

        $this->add_control(
            'infinite_loop',
            [
                'label'         => esc_html__( 'Infinite Loop', 'crowdngo' ),
                'type'          => Elementor\Controls_Manager::SWITCHER,
                'label_on'      => esc_html__( 'Yes', 'crowdngo' ),
                'label_off'     => esc_html__( 'No', 'crowdngo' ),
                'return_value'  => true,
                'default'       => true,
                'condition' => [
                    'layout_type' => 'carousel',
                ],
            ]
        );

   		$this->add_control(
            'el_class',
            [
                'label'         => esc_html__( 'Extra class name', 'crowdngo' ),
                'type'          => Elementor\Controls_Manager::TEXT,
                'placeholder'   => esc_html__( 'If you wish to style particular content element differently, please add a class name to this field and refer to it in your custom CSS file.', 'crowdngo' ),
            ]
        );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings();

        extract( $settings );

        ?>
        <div class="widget-donations <?php echo esc_attr($el_class.' '.$layout_type); ?>">
            <?php
            $args = array(
                'post_type'      => 'give_forms',
                'post_status'    => 'publish',
                'posts_per_page' => $number
            );
            $loop = new WP_Query( $args );

            if ( $loop->have_posts() ):
            ?>
                <div class="widget widget-give <?php echo esc_attr($el_class); ?>" >
                    
                    <div class="widget-content"> 
                        <?php if ( $layout_type == 'carousel' ): ?>
                            <div class="slick-carousel" data-carousel="slick" data-items="<?php echo esc_attr($columns); ?>" data-smallmedium="2" data-extrasmall="1" data-pagination="<?php echo esc_attr( $show_pagination ? 'true' : 'false' ); ?>" data-nav="<?php echo esc_attr( $show_nav ? 'true' : 'false' ); ?>" data-rows="<?php echo esc_attr( $rows ); ?>" data-infinite="<?php echo esc_attr( $infinite_loop ? 'true' : 'false' ); ?>" data-autoplay="<?php echo esc_attr( $autoplay ? 'true' : 'false' ); ?>">
                                <?php while ( $loop->have_posts() ): $loop->the_post(); ?>
                                        <?php get_template_part( 'give/loop/grid'); ?>
                                <?php endwhile; ?>
                            </div>

                        <?php elseif ( $layout_type == 'grid' ): ?>
                            <?php $count = 1; ?>
                            <?php $bcol = 12/$columns; ?>
                            <div class="row">
                                <?php while ( $loop->have_posts() ) : $loop->the_post(); ?>
                                    <div class="col-md-<?php echo esc_attr($bcol); ?> col-sm-6 <?php if($count%$columns == 1) echo 'md-clearfix'; if($count%2 == 1) echo 'sm-clearfix'; ?>">
                                        <?php get_template_part( 'give/loop/grid' ); ?>
                                    </div>
                                <?php $count++; endwhile; ?>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            <?php endif; ?>
            <?php wp_reset_postdata(); ?>
        </div>
        <?php

    }

}

Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Crowdngo_Elementor_Donations );