<?php

//namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Crowdngo_Elementor_Search_Form extends Elementor\Widget_Base {

	public function get_name() {
        return 'apus_element_search_form';
    }

	public function get_title() {
        return esc_html__( 'Apus Header Search Form', 'crowdngo' );
    }
    
	public function get_categories() {
        return [ 'crowdngo-header-elements' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
            'content_section',
            [
                'label' => esc_html__( 'Content', 'crowdngo' ),
                'tab' => Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
        
        $this->add_control(
            'show_icon',
            [
                'label' => esc_html__( 'Show Icon', 'crowdngo' ),
                'type' => Elementor\Controls_Manager::SWITCHER,
                'default' => '',
                'label_on' => esc_html__( 'Show', 'crowdngo' ),
                'label_off' => esc_html__( 'Hide', 'crowdngo' ),
            ]
        );

        $this->add_control(
            'show_text',
            [
                'label' => esc_html__( 'Show text Search', 'crowdngo' ),
                'type' => Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
                'label_on' => esc_html__( 'Show', 'crowdngo' ),
                'label_off' => esc_html__( 'Hide', 'crowdngo' ),
            ]
        );

   		$this->add_control(
            'el_class',
            [
                'label'         => esc_html__( 'Extra class name', 'crowdngo' ),
                'type'          => Elementor\Controls_Manager::TEXT,
                'placeholder'   => esc_html__( 'If you wish to style particular content element differently, please add a class name to this field and refer to it in your custom CSS file.', 'crowdngo' ),
            ]
        );

        $this->end_controls_section();
    }

	protected function render() {
        $settings = $this->get_settings();

        extract( $settings );
        ?>
        <div class="apus-search-form <?php echo esc_attr($el_class); ?>">
            <a href="javascript:void(0);" class="btn-search-icon"><i class="fa fa-search"></i></a>
            <form action="<?php echo esc_url( home_url( '/' ) ); ?>" method="get">
                
                <div class="main-search">
                    <input type="text" placeholder="<?php esc_attr_e( 'What do you need?', 'crowdngo' ); ?>" name="s" class="apus-search form-control" autocomplete="off"/>
                </div>
                
                <?php if ( crowdngo_is_give_activated() ) {  ?>
                    <input type="hidden" name="post_type" value="give_forms">
                <?php } ?>
                
                <button type="submit" class="btn btn-theme radius-0 <?php echo esc_attr(($show_icon && !$show_text)?'st_small':''); ?>">                    
                    <?php if($show_text){ ?>
                        <span class="text"><?php esc_html_e('Search', 'crowdngo'); ?></span>
                    <?php } ?>
                    <?php if($show_icon){ ?>
                        <i class="fa fa-search"></i>
                    <?php } ?>
                </button>
            </form>
        </div>
        <?php
    }
}

Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Crowdngo_Elementor_Search_Form );