<?php

//namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Crowdngo_Elementor_User_Info extends Elementor\Widget_Base {

	public function get_name() {
        return 'apus_element_user_info';
    }

	public function get_title() {
        return esc_html__( 'Apus Header User Info', 'crowdngo' );
    }
    
	public function get_categories() {
        return [ 'crowdngo-header-elements' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
            'content_section',
            [
                'label' => esc_html__( 'Content', 'crowdngo' ),
                'tab' => Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'show_login',
            [
                'label' => esc_html__( 'Show Login Button', 'crowdngo' ),
                'type' => Elementor\Controls_Manager::SWITCHER,
                'label_off' => esc_html__( 'Hide', 'crowdngo' ),
                'label_on' => esc_html__( 'Show', 'crowdngo' ),
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'show_register',
            [
                'label' => esc_html__( 'Show Register Button', 'crowdngo' ),
                'type' => Elementor\Controls_Manager::SWITCHER,
                'label_off' => esc_html__( 'Hide', 'crowdngo' ),
                'label_on' => esc_html__( 'Show', 'crowdngo' ),
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'style',
            [
                'label' => esc_html__( 'Style', 'crowdngo' ),
                'type' => Elementor\Controls_Manager::SELECT,
                'options' => array(
                    'style1' => esc_html__('Style 1', 'crowdngo'),
                    'style2' => esc_html__('Style 2', 'crowdngo'),                    
                ),
                'default' => 'style1'
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label' => esc_html__( 'Alignment', 'crowdngo' ),
                'type' => Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'crowdngo' ),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'crowdngo' ),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'crowdngo' ),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}}' => 'text-align: {{VALUE}};',
                ],
            ]
        );

   		$this->add_control(
            'el_class',
            [
                'label'         => esc_html__( 'Extra class name', 'crowdngo' ),
                'type'          => Elementor\Controls_Manager::TEXT,
                'placeholder'   => esc_html__( 'If you wish to style particular content element differently, please add a class name to this field and refer to it in your custom CSS file.', 'crowdngo' ),
            ]
        );

        

        $this->end_controls_section();
    }

	protected function render() {
        $settings = $this->get_settings();

        extract( $settings );

        if ( is_user_logged_in() ) {
            $user_id = get_current_user_id();
            $user = get_userdata( $user_id );
        ?>
            <?php if( has_nav_menu( 'my-account' ) ) { ?>
                <div class="top-wrapper-menu <?php echo esc_attr($el_class.' '.$style); ?>">
                    <div class="profile-menus flex-middle clearfix">
                        <div class="profile-avarta"><?php echo get_avatar($user_id, 32); ?></div>
                        <div class="profile-info">
                            <span><?php echo esc_html($user->data->display_name); ?></span>
                            <span class="fa fa-angle-down"></span>
                        </div>
                    </div>
                    <div class="user-account">
                        <ul class="user-log">
                            <?php
                                $args = array(
                                    'theme_location' => 'my-account',
                                    'container' => false,
                                    'menu_class' => 'list-line',
                                    'fallback_cb'     => false,
                                    'walker' => new Crowdngo_Nav_Menu(),
                                    'items_wrap' => '%3$s',
                                );
                                wp_nav_menu($args);
                            ?>
                            <li class="last"><a href="<?php echo esc_url(wp_logout_url(home_url('/'))); ?>"><?php esc_html_e('Log out ','crowdngo'); ?></a></li>
                        </ul>
                    </div>
                </div>
            <?php } ?>
        <?php } else { ?>
            <div class="top-wrapper-menu <?php echo esc_attr($el_class.' '.$style); ?>">
                <?php if ( $show_login ) { ?>
                    <a href="#apus_login_forgot_tab" class="apus-user-login wel-user"><?php esc_html_e( 'Login', 'crowdngo' ); ?></a>
                <?php } ?>
                <?php if ( $show_register ) { ?>
                    <a href="#apus_register_tab" class="apus-user-register wel-user"><?php esc_html_e( 'Register', 'crowdngo' ); ?></a>
                <?php } ?>
            </div>
        <?php }
    }
}

Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Crowdngo_Elementor_User_Info );